.. m_Librarian documentation master file, created by
   sphinx-quickstart on Wed Mar 30 22:46:31 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Документация по m_Librarian
===========================

Здесь должен быть (и, надеюсь, будет) набор программ для индексации
библиотек LibRusEc и Флибуста (точнее, zip-файлов из торрентов) и показа
содержимого индексов в командной строке, в web-интерфейсе и в
графическом интерфейсе.


Contents:

.. toctree::
   :maxdepth: 2

   before_begin
   command_line
   news


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Credits
=======

Автор: Олег Бройтман <phd@phdru.name>.

Copyright (C) 2015-2018 PhiloSoft Design.


License
=======

GPL.
